==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/sr-CS/admin/hardware/form.php <==
<?php

return array(
	'bulk_delete'		=> 'Potvrda grupnog brisanja imovine',
  'bulk_delete_help'	=> 'Pregledajte stavke za grupno brisanje. Jednom izbrisana, ta se sredstva mogu vratiti, ali više neće biti povezana s korisnicima koji su trenutno dodeljeni.',
  'bulk_delete_warn'	=> 'Izbrisaćete: asset_count assets.',
	'bulk_update'		=> 'Grupno ažuriranje imovine',
	'bulk_update_help'	=> 'Ova forma vam omogućava da ažururate više stavki odjednom. Popunite samo polja koja želite da izmenite. Nepopunjena polja ostaće nepromenjena. ',
	'bulk_update_warn'	=> 'Nameravate da manjate svojstva: imovine asset_count.',
    'checkedout_to'		=> 'Checked Out To',
    'checkout_date'		=> 'Checkout Date',
    'checkin_date'		=> 'Checkin Date',
    'checkout_to'		=> 'Checkout to',
    'cost'				=> 'Cena nabavke',
    'create'			=> 'Kreiraj resurs',
    'date'				=> 'Datum kupovine',
    'depreciation'	    => 'Amortizacija',
    'depreciates_on'	=> 'Depreciates On',
    'default_location'	=> 'Podrazumevana lokacija',
    'eol_date'			=> 'EOL datum',
    'eol_rate'			=> 'EOL stopa',
    'expected_checkin'  => 'Očekivani datum provere',
    'expires'			=> 'Ističe',
    'fully_depreciated'	=> 'Potpuno amortizovano',
    'help_checkout'		=> 'Ako želite odmah dodijeliti ovaj resurs, odaberite "Spreman za korošćenje" iz gornje liste statusa. ',
    'mac_address'		=> 'MAC Adresa',
    'manufacturer'		=> 'Proizvođač',
    'model'				=> 'Model',
    'months'			=> 'meseci',
    'name'				=> 'Naziv imovine',
    'notes'				=> 'Zabeleške',
    'order'				=> 'Broj narudžbine',
    'qr'				=> 'QR Code',
    'requestable'		=> 'Korisnici mogu zatražiti ovaj resurs',
    'select_statustype'	=> 'Odaberite vrstu statusa',
    'serial'			=> 'Serial',
    'status'			=> 'Status',
    'tag'				=> 'Oznaka imovine',
    'update'			=> 'Ažuriranje imovine',
    'warranty'			=> 'Garancija',
		'warranty_expires'		=> 'Garancija ističe',
    'years'				=> 'godina',
)
;

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/sr-CS/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Potvrda grupnog brisanja imovine',
  'bulk_delete_help'	=> 'Pregledajte stavke za grupno brisanje. Jednom izbrisana, ta se sredstva mogu vratiti, ali više neće biti povezana s korisnicima koji su trenutno dodeljeni.',
  'bulk_delete_warn'	=> 'Izbrisaćete: asset_count assets.',
    'bulk_update'		=> 'Grupno ažuriranje imovine',
    'bulk_update_help'	=> 'Ova forma vam omogućava da ažururate više stavki odjednom. Popunite samo polja koja želite da izmenite. Nepopunjena polja ostaće nepromenjena. ',
    'bulk_update_warn'	=> 'Nameravate da manjate svojstva: imovine asset_count.',
    'checkedout_to'		=> 'Checked Out To',
    'checkout_date'		=> 'Checkout Date',
    'checkin_date'		=> 'Checkin Date',
    'checkout_to'		=> 'Checkout to',
    'cost'				=> 'Cena nabavke',
    'create'			=> 'Kreiraj resurs',
    'date'				=> 'Datum kupovine',
    'depreciation'	    => 'Amortizacija',
    'depreciates_on'	=> 'Depreciates On',
    'default_location'	=> 'Podrazumevana lokacija',
    'eol_date'			=> 'EOL datum',
    'eol_rate'			=> 'EOL stopa',
    'expected_checkin'  => 'Očekivani datum provere',
    'expires'			=> 'Ističe',
    'fully_depreciated'	=> 'Potpuno amortizovano',
    'help_checkout'		=> 'Ako želite odmah dodijeliti ovaj resurs, odaberite "Spreman za korošćenje" iz gornje liste statusa. ',
    'mac_address'		=> 'MAC Adresa',
    'manufacturer'		=> 'Proizvođač',
    'model'				=> 'Model',
    'months'			=> 'meseci',
    'name'				=> 'Naziv imovine',
    'notes'				=> 'Zabeleške',
    'order'				=> 'Broj narudžbine',
    'qr'				=> 'QR Code',
    'requestable'		=> 'Korisnici mogu zatražiti ovaj resurs',
    'select_statustype'	=> 'Odaberite vrstu statusa',
    'serial'			=> 'Serial',
    'status'			=> 'Status',
    'tag'				=> 'Oznaka imovine',
    'update'			=> 'Ažuriranje imovine',
    'warranty'			=> 'Garancija',
        'warranty_expires'		=> 'Garancija ističe',
    'years'				=> 'godina',
    'asset_location' => 'Update Asset Location',
    'asset_location_update_default_current' => 'Update default location AND actual location',
    'asset_location_update_default' => 'Update only default location',
    'asset_not_deployable' => 'That asset status is not deployable. This asset cannot be checked out.',
    'asset_deployable' => 'That status is deployable. This asset can be checked out.',
    'processing_spinner' => 'Processing...',
];
